@@ -10,6 +10,13 @@
 #include "hash.h"
 #include "utilstrencodings.h"
 
+void CPureBlockHeader::SetBaseVersion(int32_t nBaseVersion, int32_t nChainId)
+{
+    assert(nBaseVersion >= 1 && nBaseVersion < VERSION_AUXPOW);
+    assert(!IsAuxpow());
+    nVersion = nBaseVersion | (nChainId * VERSION_CHAIN_START);
+}
+
 uint256 CPureBlockHeader::GetHash() const
 {
     return SerializeHash(*this);
