@@ -1,4 +1,4 @@
-<TS language="sq" version="2.0">
+<TS language="sq" version="2.1">
 <context>
     <name>AddressBookPage</name>
     <message>
@@ -21,14 +21,14 @@
         <source>&amp;Copy</source>
         <translation>&amp;Kopjo</translation>
     </message>
-    <message>
-        <source>&amp;Copy Address</source>
-        <translation>&amp;Kopjo adresen</translation>
-    </message>
     <message>
         <source>Delete the currently selected address from the list</source>
         <translation>Fshi adresen e selektuar nga lista</translation>
     </message>
+    <message>
+        <source>Export the data in the current tab to a file</source>
+        <translation>Eksporto të dhënat e skedës korrente në një skedar</translation>
+    </message>
     <message>
         <source>&amp;Delete</source>
         <translation>&amp;Fshi</translation>
@@ -45,15 +45,43 @@
         <source>Much receiving addresses</source>
         <translation>Duke marr adresen</translation>
     </message>
+    <message>
+        <source>These are your Dogecoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
+        <translation>Këto janë Dogecoin adresat e juaja për të dërguar pagesa. Gjithmon kontrolloni shumën dhe adresën pranuese para se të dërgoni monedha.</translation>
+    </message>
+    <message>
+        <source>These are your Dogecoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
+        <translation>Këto janë Dogecoin adresat e juaja për të pranuar pagesa. Rekomandohet që gjithmon të përdorni një adresë të re për çdo transaksion.</translation>
+    </message>
+    <message>
+        <source>&amp;Copy Address</source>
+        <translation>&amp;Kopjo adresen</translation>
+    </message>
+    <message>
+        <source>Copy &amp;Label</source>
+        <translation>Kopjo &amp;Etiketë</translation>
+    </message>
     <message>
         <source>&amp;Edit</source>
         <translation>&amp;Ndrysho</translation>
     </message>
+    <message>
+        <source>Export Address List</source>
+        <translation>Eksporto listën e adresave</translation>
+    </message>
     <message>
         <source>Comma separated file (*.csv)</source>
         <translation>Skedar i ndarë me pikëpresje(*.csv)</translation>
     </message>
-    </context>
+    <message>
+        <source>Exporting Failed</source>
+        <translation>Eksportimi dështoj</translation>
+    </message>
+    <message>
+        <source>There was an error trying to save the address list to %1. Please try again.</source>
+        <translation>Gabim gjatë ruajtjes së listës së adresave në %1. Ju lutem provoni prapë.</translation>
+    </message>
+</context>
 <context>
     <name>AddressTableModel</name>
     <message>
@@ -145,13 +173,16 @@
     </message>
     </context>
 <context>
-    <name>BitcoinGUI</name>
+    <name>BanTableModel</name>
+    </context>
+<context>
+    <name>DogecoinGUI</name>
     <message>
         <source>Synchronizing with network...</source>
         <translation>Duke u sinkronizuar me rrjetin...</translation>
     </message>
     <message>
-        <source>&amp;Overview</source>
+        <source>&amp;Wow</source>
         <translation>&amp;Përmbledhje</translation>
     </message>
     <message>
@@ -174,6 +205,10 @@
         <source>&amp;Options...</source>
         <translation>&amp;Opsione</translation>
     </message>
+    <message>
+        <source>&amp;Much receiving addresses...</source>
+        <translation>Duke marr adresen</translation>
+    </message>
     <message>
         <source>Change the passphrase used for wallet encryption</source>
         <translation>Ndrysho frazkalimin e përdorur per enkriptimin e portofolit</translation>
@@ -187,11 +222,11 @@
         <translation>Portofol</translation>
     </message>
     <message>
-        <source>&amp;Send</source>
+        <source>&amp;Such Send</source>
         <translation>&amp;Dergo</translation>
     </message>
     <message>
-        <source>&amp;Receive</source>
+        <source>&amp;Much Receive</source>
         <translation>&amp;Merr</translation>
     </message>
     <message>
@@ -214,18 +249,6 @@
         <source>Tabs toolbar</source>
         <translation>Shiriti i mjeteve</translation>
     </message>
-    <message>
-        <source>Dogecoin Core</source>
-        <translation>Berthama Dogecoin</translation>
-    </message>
-    <message>
-        <source>&amp;About Dogecoin Core</source>
-        <translation>Rreth Berthames Dogekoin</translation>
-    </message>
-    <message>
-        <source>%1 and %2</source>
-        <translation>%1 dhe %2</translation>
-    </message>
     <message>
         <source>%1 behind</source>
         <translation>%1 Pas</translation>
@@ -262,9 +285,6 @@
         <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
         <translation>Portofoli po &lt;b&gt; enkriptohet&lt;/b&gt; dhe është &lt;b&gt; i kyçur&lt;/b&gt;</translation>
     </message>
-</context>
-<context>
-    <name>ClientModel</name>
     </context>
 <context>
     <name>CoinControlDialog</name>
@@ -353,18 +373,10 @@
     </context>
 <context>
     <name>HelpMessageDialog</name>
-    <message>
-        <source>Dogecoin Core</source>
-        <translation>Berthama Dogecoin</translation>
-    </message>
     <message>
         <source>version</source>
         <translation>versioni</translation>
     </message>
-    <message>
-        <source>About Dogecoin Core</source>
-        <translation>Rreth Berthames Dogekoin</translation>
-    </message>
     </context>
 <context>
     <name>Intro</name>
@@ -372,19 +384,18 @@
         <source>Welcome</source>
         <translation>Miresevini</translation>
     </message>
-    <message>
-        <source>Welcome to Dogecoin Core.</source>
-        <translation>Miresevini ne Berthamen Dogecoin</translation>
-    </message>
-    <message>
-        <source>Dogecoin Core</source>
-        <translation>Berthama Dogecoin</translation>
-    </message>
     <message>
         <source>Error</source>
         <translation>Problem</translation>
     </message>
     </context>
+<context>
+    <name>ModalOverlay</name>
+    <message>
+        <source>Form</source>
+        <translation>Formilarë</translation>
+    </message>
+    </context>
 <context>
     <name>OpenURIDialog</name>
     </context>
@@ -394,6 +405,10 @@
         <source>Options</source>
         <translation>Opsionet</translation>
     </message>
+    <message>
+        <source>W&amp;allet</source>
+        <translation>Portofol</translation>
+    </message>
     </context>
 <context>
     <name>OverviewPage</name>
@@ -414,12 +429,23 @@
         <source>Amount</source>
         <translation>Sasia</translation>
     </message>
+    <message>
+        <source>%1 and %2</source>
+        <translation>%1 dhe %2</translation>
+    </message>
+    </context>
+<context>
+    <name>QObject::QObject</name>
     </context>
 <context>
     <name>QRImageWidget</name>
     </context>
 <context>
     <name>RPCConsole</name>
+    <message>
+        <source>&amp;Information</source>
+        <translation>Informacion</translation>
+    </message>
     <message>
         <source>&amp;Open</source>
         <translation>&amp;Hap</translation>
@@ -436,16 +462,28 @@
         <source>Unknown</source>
         <translation>i/e panjohur</translation>
     </message>
-    </context>
+</context>
 <context>
     <name>ReceiveCoinsDialog</name>
+    <message>
+        <source>&amp;Amount:</source>
+        <translation>Shuma:</translation>
+    </message>
     <message>
         <source>&amp;Label:</source>
         <translation>&amp;Etiketë:</translation>
     </message>
+    <message>
+        <source>Clear</source>
+        <translation>Pastro</translation>
+    </message>
     </context>
 <context>
     <name>ReceiveRequestDialog</name>
+    <message>
+        <source>Copy &amp;Address</source>
+        <translation>&amp;Kopjo adresen</translation>
+    </message>
     <message>
         <source>Address</source>
         <translation>Adresë</translation>
@@ -469,10 +507,6 @@
         <source>Label</source>
         <translation>Etiketë</translation>
     </message>
-    <message>
-        <source>Amount</source>
-        <translation>Sasia</translation>
-    </message>
     <message>
         <source>(no label)</source>
         <translation>(pa etiketë)</translation>
@@ -484,6 +518,10 @@
         <source>Send Coins</source>
         <translation>Dërgo Monedha</translation>
     </message>
+    <message>
+        <source>Insufficient funds!</source>
+        <translation>Fonde te pamjaftueshme</translation>
+    </message>
     <message>
         <source>Amount:</source>
         <translation>Shuma:</translation>
@@ -512,7 +550,7 @@
         <source>(no label)</source>
         <translation>(pa etiketë)</translation>
     </message>
-    </context>
+</context>
 <context>
     <name>SendCoinsEntry</name>
     <message>
@@ -523,10 +561,6 @@
         <source>Pay &amp;To:</source>
         <translation>Paguaj &amp;drejt:</translation>
     </message>
-    <message>
-        <source>Enter a label for this address to add it to your address book</source>
-        <translation>Krijoni një etiketë për këtë adresë që t'ja shtoni librit të adresave</translation>
-    </message>
     <message>
         <source>&amp;Label:</source>
         <translation>&amp;Etiketë:</translation>
@@ -543,6 +577,17 @@
         <source>Alt+P</source>
         <translation>Alt+P</translation>
     </message>
+    <message>
+        <source>Pay To:</source>
+        <translation>Paguaj drejt:</translation>
+    </message>
+    <message>
+        <source>Enter a label for this address to add it to your address book</source>
+        <translation>Krijoni një etiketë për këtë adresë që t'ja shtoni librit të adresave</translation>
+    </message>
+</context>
+<context>
+    <name>SendConfirmationDialog</name>
     </context>
 <context>
     <name>ShutdownWindow</name>
@@ -564,10 +609,6 @@
     </context>
 <context>
     <name>SplashScreen</name>
-    <message>
-        <source>Dogecoin Core</source>
-        <translation>Berthama Dogecoin</translation>
-    </message>
     <message>
         <source>[testnet]</source>
         <translation>[testo rrjetin]</translation>
@@ -590,34 +631,34 @@
         <source>%1 confirmations</source>
         <translation>%1 konfirmimet</translation>
     </message>
-    <message>
-        <source>Date</source>
-        <translation>Data</translation>
-    </message>
-    <message>
-        <source>Amount</source>
-        <translation>Sasia</translation>
-    </message>
     <message>
         <source>, has not been successfully broadcast yet</source>
         <translation>, nuk është transmetuar me sukses deri tani</translation>
     </message>
+    <message>
+        <source>Date</source>
+        <translation>Data</translation>
+    </message>
     <message>
         <source>unknown</source>
         <translation>i/e panjohur</translation>
     </message>
-</context>
+    <message>
+        <source>Transaction</source>
+        <translation>transaksionit</translation>
+    </message>
+    <message>
+        <source>Amount</source>
+        <translation>Sasia</translation>
+    </message>
+    </context>
 <context>
     <name>TransactionDescDialog</name>
-    <message>
-        <source>Transaction details</source>
-        <translation>Detajet e transaksionit</translation>
-    </message>
     <message>
         <source>This pane shows a detailed description of the transaction</source>
         <translation>Ky panel tregon një përshkrim të detajuar të transaksionit</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>TransactionTableModel</name>
     <message>
@@ -628,6 +669,10 @@
         <source>Type</source>
         <translation>Lloji</translation>
     </message>
+    <message>
+        <source>Label</source>
+        <translation>Etiketë</translation>
+    </message>
     <message>
         <source>Open until %1</source>
         <translation>Hapur deri më %1</translation>
@@ -644,10 +689,6 @@
         <source>Generated but not accepted</source>
         <translation>I krijuar por i papranuar</translation>
     </message>
-    <message>
-        <source>Label</source>
-        <translation>Etiketë</translation>
-    </message>
     <message>
         <source>Received with</source>
         <translation>Marrë me</translation>
@@ -668,6 +709,10 @@
         <source>(n/a)</source>
         <translation>(p/a)</translation>
     </message>
+    <message>
+        <source>(no label)</source>
+        <translation>(pa etiketë)</translation>
+    </message>
     </context>
 <context>
     <name>TransactionView</name>
@@ -707,6 +752,10 @@
         <source>Address</source>
         <translation>Adresë</translation>
     </message>
+    <message>
+        <source>Exporting Failed</source>
+        <translation>Eksportimi dështoj</translation>
+    </message>
     </context>
 <context>
     <name>UnitDisplayStatusBarControl</name>
@@ -723,9 +772,21 @@
 </context>
 <context>
     <name>WalletView</name>
+    <message>
+        <source>Export the data in the current tab to a file</source>
+        <translation>Eksporto të dhënat e skedës korrente në një skedar</translation>
+    </message>
     </context>
 <context>
-    <name>bitcoin-core</name>
+    <name>dogecoin-core</name>
+    <message>
+        <source>Options:</source>
+        <translation>Opsionet:</translation>
+    </message>
+    <message>
+        <source>Dogecoin Core</source>
+        <translation>Berthama Dogecoin</translation>
+    </message>
     <message>
         <source>Information</source>
         <translation>Informacion</translation>
